@@ -9,7 +9,8 @@ from argh import arg
 from optimus.builder.assets import build_assets
 from optimus.builder.pages import PageBuilder
 from optimus.conf import import_project_module
-from optimus.init import init_logging, initialize, display_settings
+from optimus.logs import init_logging
+from optimus.utils import initialize, display_settings
 
 @arg('--settings', default='settings', help="Python path to the settings module")
 @arg('--loglevel', default='info', choices=['debug','info','warning','error','critical'], help="The minimal verbosity level to limit logs output")
